@@ -70,6 +70,7 @@ new EventsRuleToStepFunction(scope: Construct, id: string, props: EventsRuleToSt
 |:-------------|:----------------|-----------------|
 |eventsRule|[`events.Rule`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.Rule.html)|Returns an instance of events.Rule created by the construct|
 |stateMachine|[`sfn.StateMachine`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachine.html)|Returns an instance of sfn.StateMachine created by the construct|
+|stateMachineLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for StateMachine|
 |cloudwatchAlarms|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
 
 ## Default settings
@@ -108,6 +109,7 @@ from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_events
+import aws_cdk.aws_logs
 import aws_cdk.aws_stepfunctions
 import aws_cdk.core
 
@@ -159,6 +161,11 @@ class EventsRuleToStepFunction(
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return jsii.get(self, "stateMachine")
 
+    @builtins.property
+    @jsii.member(jsii_name="stateMachineLogGroup")
+    def state_machine_log_group(self) -> aws_cdk.aws_logs.LogGroup:
+        return jsii.get(self, "stateMachineLogGroup")
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-events-rule-step-function.EventsRuleToStepFunctionProps",
